Enum of all possible notifications from the agent to the client.
Summary
Types
@type t() :: {:session_notification, ACP.SessionNotification.t()} | {:ext_notification, ACP.ExtNotification.t()}
Enum of all possible notifications from the agent to the client.
@type t() :: {:session_notification, ACP.SessionNotification.t()} | {:ext_notification, ACP.ExtNotification.t()}