Resource content that can be embedded in a message (untagged union).
Summary
Types
@type t() :: ACP.TextResourceContents.t() | ACP.BlobResourceContents.t()
Resource content that can be embedded in a message (untagged union).
@type t() :: ACP.TextResourceContents.t() | ACP.BlobResourceContents.t()