ACP.Unstable (agent_client_protocol v0.1.0)

Copy Markdown View Source

Unstable types that are not yet part of the ACP specification.

These types correspond to Rust feature-gated types behind #[cfg(feature = "unstable_*")]. They may be removed or changed at any point.