An agent-side connection to a client.
Wraps an ACP.Connection with the AgentSide decoder, providing convenience functions that implement the Client interface (request_permission, write_text_file, session_notification, etc.) for making requests to the client from the agent side.
Summary
Functions
Start an agent-side connection.
Functions
Start an agent-side connection.
Options:
:handler- Module implementing ACP.Agent behaviour (handles incoming client requests):handler_state- State passed to handler:input- Input IO device (default: :stdio):output- Output IO device (default: :stdio):name- Optional GenServer name