A client-side connection to an agent.
Wraps an ACP.Connection with the ClientSide decoder, providing convenience functions that implement the Agent interface (initialize, prompt, etc.) for making requests to the agent from the client side.
Summary
Functions
Start a client-side connection.
Functions
Start a client-side connection.
Options:
:handler- Module implementing ACP.Client behaviour (handles incoming agent requests):handler_state- State passed to handler:input- Input IO device (default: :stdio):output- Output IO device (default: :stdio):name- Optional GenServer name